##  创建账户

### API路径

    services/v3/rest/user/openAccount

### 请求header参数

| 字段 | 类型 | 说明 | 示例 |
|---|---|---|---|
| x-ak-key | string | 当前分销的AK值 | |
| x-ak-ts | string | 毫秒级时间戳 |
| x-ak-pin | string | 经过加密算法生成的加密参数([api加密认证方式](http://apidoc.weiwenjia.com/docs/skb-open-dev/index-12026657.md)) |

###   
请求方法

    POST
    Content-Type: application/json

### 请求Body参数示例：

    {
    	"uid": "uid_2",
    	"parent_user": "uid_1",
    	"username": "用户1",
    	"role": "mainaccount",
    	"company_name": "xx公司",
    	"email": "xx@xx.com",
    	"mobile": "188xxxxxxxx",
    	"expiry_time": 1655497185391,
    	"notifyCallback": "http:xxxx",
    	"integrationCallback": "http:xxxx",
    	"meals": [
    		{
    		"type": "1+5套餐"	
    		}
    	]
    	"extra": {
    		"enableCall": true,
    		"enableTask": true,
    		"taskQuota": 100
    	}
    	"plugin": ["pluginid_xxx"]
    	"integrationCallback": "http:xxxx"
    }

### body参数说明：

| 参数 | 类型 | 说明 | 示例 |
|---|---|---|---|
| `uid` | string | 必须，客户系统唯一用户编码 | &nbsp; |
| `parent_user` | string | 选填。创建子账户时，必须提供主账户的客户系统唯一用户编码。创建主账户时，允许不传或提供客户系统唯一用户编码，不能为空值 | &nbsp; |
| `username` | string | 必须，客户系统唯一用户名称 | &nbsp; |
| `role` | string | 必须，账户角色，必须是'mainaccount'或'subaccount', 对应'主账户'或'子账户' | &nbsp; |
| `company_name` | string | 必须，公司名称 | &nbsp; |
| `email` | string | 选填，客户邮箱。不填时，放空字符串，"" | &nbsp; |
| `mobile` | string | 选填，客户移动电话。不填时，放空字符串，"" | &nbsp; |
| `expiry_time` | long | 选填，客户系统唯一用户对应的账户过期时间戳(毫秒级)，新增主账户时必填，新增子账户时不需要，过期时间跟他的主账户一致 | &nbsp; |
| `notifyCallback` | string | 选填，添加线索池时回调API地址 | &nbsp; |
| `integrationCallback` | string | 选填，指定推送该用户的集成系统数据的回调地址（如果有指定用户自己的集成系统回调地址，则优先使用自己的；如果没有，则使用分销配置下统一的回调地址）  |
| scheduleTaskListUrl | string | 选填，指定该用户 获取集成系统外呼计划列表 的调用地址（如果有指定用户自己的外呼计划列表调用地址，则优先使用自己的；如果没有，则使用分销配置下统一的外呼计划列表调用地址）|   
| `meals[]` | array | 选填，创建主账户此项为必填，创建子账户此项不允许填写。不填时，放空数组，[] | &nbsp; |
| `meals[].type` | String | 必须，主账户套餐名称 | &nbsp; |
| `extra.enableCall` | boolean | 选填，主账户是否启用外呼。不填时，默认为false | &nbsp; |
| `extra.enableTask` | int | 选填，主账户是否开通任务中心。不填时，默认为false | &nbsp; |
| `extra.taskQuota` | int | 选填，主账户任务中心额度。不填时，默认为0 | 上限5万 |
| `plugin` | array | 选填，主账户开启的集成系统id列表 | &nbsp; |

### 返回结果

JSON示例

    {
        "error_code": 0,
        "success":true
        "message": "",
        "data": { 
            "token":'Bearer eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJfaWQiOiI1OTU2MzJmNTgzM2JiMDQwNWRmZmJlNmMiLCJy
                  b2xlIjoicm9vdCIsInNlcXVlbmNlIjoxODIsImlhdCI6MTUwMjQxNjAzMiwiZXhwIjoxNTAyNDQ0ODMyfQ.
                  vIYxX_gssXJNqPWY-MD9T3qhcYpJzE3SUL20ChLHt3s'
           "expiry_date": "1505909258494" 
        }
      }
    
    
    返回的 token 最终会以GET请求对应的搜客宝管理平台的页面地址，如
    注意：目前token的有效期通过返回的expiry_date来传达，失效时间8小时
    
    
    登录搜客宝管理平台样例
    https://${host}/login?access_token=Bearer%20eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJfaWQiOiI1OTU2MzJmNTgzM2JiMDQwNWRmZmJlNmMiLCJyb2xlIjoicm9vdCIsInNlcXVlbmNlIjoxODIsImlhdCI6MTUwMjQxNjAzMiwiZXhwIjoxNTAyNDQ0ODMyfQ.vIYxX_gssXJNqPWY-MD9T3qhcYpJzE3SUL20ChLHt3s

### 返回错误代码以及处理方式

| 错误码 | 处理方式参考 | 说明 |
|---|---|---|
| 403 | 检查是否禁用了游客登陆权限 | 游客，无效的授权 |
| 410 | 检查x-ak-key请求头是否存在，是否类型正确 | &nbsp; |
| 412 | 检查x-ak-key是否是有效的 | &nbsp; |
| 5011 | 检查user\_token是否存在，是否类型正确 | &nbsp; |
| 5015 | 检查回调接口是否正常 | 回调失败 |
| 5020 | 检查要创建的主账户套餐是否符合账户上一级的套餐信息 | &nbsp; |
| 5024 | 检查登录回调数据是否和wiki上完全一致 | &nbsp; |
| 5026 | 检查expiry\_time参数是否合法 | expiry\_time不能小于当前时间或者大于分销过期时间 |
| 5026 | 检查expiry\_time参数是否为空 | 参数expiry\_time不能为空 |
| 5027 | 检查分销账户是否已经失效或禁用 | &nbsp; |
| 5029 | 检查账户是否位于该分销账户下 | &nbsp; |
| 5032 | 检测当前用户是否禁用 | &nbsp; |
| 5033 | 检查当前用户是否过期 | &nbsp; |
| 6015 | 创建子账户时，检查主账号下子账户数是否到达上限 | &nbsp; |
| 6101 | 检查uid是否已经绑在其他搜客宝用户上 | &nbsp; |
| 6107 | 检查手机号码是否已被其他用户注册 | &nbsp; |
| 6110 | 检查账户角色是否正确 | 账户角色不正确 |
| 6111 | 检查账户手机号是否合法 | 当前注册手机号码不合法 |
| 6113 | 检查邮箱是否已被其他用户注册 | &nbsp; |
| 6114 | 当注册用户为子账户或游客时，检测主账户是否已经在搜客宝注册 | 主账户不存在或无效 |
| 6115 | 当注册用户为主账户时，检测套餐名称是否正确 | &nbsp; |
| 6116 | 当注册用户为主账户时，检测套餐增值服务是否合法（赠送子账户，月数是否超限等） | &nbsp; |
| 6117 | 子账户超限 | &nbsp; |
| 6020 | 检查套餐时间是否超限 | &nbsp; |