##  查询账套信息

### API路径

    services/v2/rest/user/package

### 请求header参数

| 字段 | 类型 | 说明 | 示例 |
|---|---|---|---|
| x-ak-key | string | 当前分销的AK值 | |
| x-ak-ts | string | 毫秒级时间戳 |
| x-ak-pin | string | 经过加密算法生成的加密参数([api加密认证方式](http://apidoc.weiwenjia.com/docs/skb-open-dev/index-12026657.md)) |

### 请求方法

    GET

### 请求参数

| 字段 | 类型 | 说明 | 示例 |
|---|---|---|---|
| mobile | string | 主/子账户手机号码 | 13345664445 |

### 调用样例

`https://${host}/services/v2/rest/user/package?mobile=13311114441`

### 返回结果

| 字段 | 类型 | 说明 | 是否必须 |
|---|---|---|---|
| error\_code | int | 错误码 | Y |
| success | boolean | 是否成功 | Y |
| message | string | 错误提示消息 | Y |
| data.uid | string | 第三方账户系统唯一ID，如果API对接绑定过，会有值，否则为空字符串 | Y |
| data.user\_id | string | 搜客宝账户系统唯一ID | Y |
| data.mobile | string | 搜客宝账户系统该用户手机 | Y |
| data.expiry\_time | int | 搜客宝账户系统该用户过期时间 | Y |
| data.company\_name | string | 搜客宝账户系统该用户企业名称 | Y |
| data.status | int | 搜客宝账户系统该用户状态，1表示正常，2表示未激活，3表示禁用，4表示已过期 | Y |
| data.role | string | 搜客宝账户系统该用户角色 | Y |
| data.package.meals | array | 该用户所在账套的套餐情况,对象的属性全部为必须 | Y |
| data.package.subaccounts | array | 该用户所在账套的子账户，账户都包含必须属性uid，user\_id，mobile，status，role | Y |
| data.package.mainaccount | array | 该用户所在账套的主账户，账户都包含必须属性uid，user\_id，mobile，status，role | Y |

JSON示例

    {
      "error_code": 0,
      "success":true
      "message": "",
      "data": {
      	  "uid":"5926cesdfsdfe5a600422292fd2676", #此uid为第三方账户系统唯一用户编号
          "user_id":'5926cee5a600422292fd2676',#此user_id为搜客宝系统账户系统唯一用户编号
          "mobile": '133222121213', 电话
          "status": 1, #1表示正常，2表示未激活，3表示禁用，4表示已过期
          "expiry_time": 4102329600000, #账户过期时间
          "company": " **** 有限公司" #主账户企业名称
          "role": "mainaccount", #账户类型mainaccount主账户，subaccount子账户
          "package": {
          	"meals": [{
                  "renewal" : NumberInt(12), #更新周期
    		"unit" : NumberInt(3), #更新单位，1表示日，2表示月，3表示年
                  "subaccounts" : NumberInt(4), #子账户数量
                  "view_contact_num" : NumberInt(200), #每日可查看数量
                  "gonghai_volume" : NumberInt(2000), #公海容量
                  "mainaccounts" : NumberInt(1), #主账户数量
                  "type" : "A", #套餐类型
                  "enableCall": true, #是否开通外呼
                  "extraExpiry": 3, #额外赠送月数
                  "extraSubCount": 3, #额外赠送子账户数
                  "clue_volume" : NumberInt(5000), #线索池容量
                  "total_amount" : 500 #如果当前是大客户角色，才有该属性，表名当前套餐可开的数量
        	}],
          	"subaccounts": [
                  {
                    "uid":"", #未绑定过，此值为空
                    "user_id":'5926cee5a600422292fd2676',#此user_id为搜客宝系统账户系统唯一用户编号
                    "mobile": '133222121213', 电话
                    "status": 1, #1表示正常，2表示未激活，3表示禁用，4表示已过期
                    "role": "mainaccount", #账户类型mainaccount主账户，subaccount子账户
                  },
                  {
                    "uid": "592dss6cee5a600422292fd2676",#此uid为第三方账户系统唯一用户编号
                    "user_id":'5926cee5a600422292fd2676',#此user_id为搜客宝系统账户系统唯一用户编号
                    "mobile": '133222121213', 电话
                    "status": 1, #1表示正常，2表示未激活，3表示禁用，4表示已过期
                    "role": "mainaccount", #账户类型mainaccount主账户，subaccount子账户
                  }
          	],
            "mainaccount": {
                  "uid": "",#未绑定过，此值为空
                  "user_id":'5926cee5a600422292fd2676',#搜客宝账户ID
                  "mobile": '133222121213', 电话
                  "status": 1, #1表示正常，2表示未激活，3表示禁用，4表示已过期
                  "role": "mainaccount", #账户类型mainaccount主账户，subaccount子账户
            }
          }
      }
    }

### 返回错误代码以及处理方式

| code | 处理方式 | 说明 |
|---|---|---|
| 400 | 检查是否所在参数是否存在，是否类型正确 | ak参数缺少 或者 手机号码不存在或非法 |
| 412 | 检查AK是否有效 | Access Key 已被禁用 |
| 5027 | 检查分销账户是否有效或禁用 | 分销账户已失效 |
| 5029 | 检查手机号是否正确 | 手机号码对应账户不存在 |
| 5032 | 检测当前用户是否禁用 | &nbsp; |
| 5033 | 检查当前用户是否过期 | &nbsp; |
| 6110 | 检查该账户角色是否正确，只有主账户或者子账户可以查询账套信息 | &nbsp; |