## 企业联系方式

### 接口说明
> 返回手机、固定电话、email、qq
> 返回职位信息
> 按照公司数量计量


### API路径

    services/v4/rest/enterprise/batch/contactWashList

### 请求方法

GET

###   请求参数

| 参数 | 类型 | 说明 | 示例 |
|---|---|---|---|
| keywords | list | 企业名称或企业唯一标识(pid)，统一信用代码，工商注册码，历史名称，需精准匹配。list类型，最大一次支持50个企业的查询 | &nbsp; |
| type | list | 指定需要返回的联系方式类型（1=手机 2=固话 3=qq 4=邮箱），默认返回全部 | &nbsp; |



### 调用样例

    https://${host}/services/v4/rest/enterprise/batch/contactWashList?keywords[]=上海xx公司&keywords[]=上海yy公司&type[]=1&type[]=3

### 返回结果

JSON示例
```json
    {
    "error_code": 0,
    "message": "",
    "data": [
        {
            "pid": "fd72d7c9ae9f2dd8a19b094089dddd", // 企业唯一id
            "keyword": "上海xx公司", // 查询关键字(对应keywords中参数)
            "contacts": [
                {
                    "contact": "",  // 联系人名字
                    "position": "", // 职位
                    "repeat_amount": 0, // 号码重复数
                    "status": "2000", // 号码状态(状态码说明详见下方状态码说明)
                    "type": 1, // 1=手机 2=固话 3=qq 4=邮箱
                    "content": "150********", // 联系方式
                    "sources": [ // 号码来源
                        {
                            "contact": "", // 渠道联系人名字
                            "source_name": "招投标信息" // 渠道名
                        }
                    ],
					"labels" : [ "推荐" ], // 标签
                },
                {
                    "contact": "",
                    "position": "",
                    "repeat_amount": 1,
                    "status": "",
                    "type": 2,
                    "content": "0400606****",
                    "sources": [
                        {
                            "contact": "",
                            "source_name": "工商企业年报2020"
                        }
                    ]，
					"labels" : null, // 标签
                },
                {
                    "contact": "",
                    "position": "",
                    "repeat_amount": 0,
                    "status": "",
                    "type": 4,
                    "content": "****@126.com",
                    "sources": [
                        {
                            "contact": "",
                            "source_name": "工商企业年报2017"
                        }
                    ],
					"labels" : [ "关键" ], // 标签
                },
                {
                    "contact": "郭",
                    "position": "",
                    "repeat_amount": 0,
                    "status": "",
                    "type": 3,
                    "content": "26447****",
                    "sources": [
                        {
                            "contact": "郭",
                            "source_name": "顺企网"
                        }
                    ],
					"labels" : [ "关键" ], // 标签
                }
            ]
        }
    ]
}
```

### 号码状态说明
固话，qq，邮箱的状态码为空，手机号经过清洗后存在状态码

| 状态码 | 说明 |
|---|---|
| 1000 | 实号 |
| 2000 | 沉默号 |
| 2001 | 停机 |
| 2002 | 空号 |
| 2003 | 风险号 |
| 3000 | 库无 |
| 3001 | 非法号码 |
| 3002 | 未验证 |

### 返回字段说明

| 参数 | 类型 | 说明 |
| --- | --- | --- |
| error_code | int | 错误码(详见错误码说明) |
| message | string | 异常信息 |
| data | list | 返回具体数据(详见下方data数据说明) |

data 返回字段说明

| 参数 | 类型 | 说明 |
| --- | --- | --- |
| pid | string | 企业唯一编码 |
| keyword | string | 查询关键字(对应keywords中参数) |
| contacts | list | 企业联系方式（详见下方contacts数据说明） |

contacts 返回字段说明

| 参数 | 类型 | 说明 |
| --- | --- | --- |
| contact | string | 联系人 |
| position | string | 职位 |
| repeat_amount | int | 号码重复数
| status | string | 状态码(详见状态码说明) |
| type | int | 号码类型(1=手机 2=固话 3=qq 4=邮箱) |
| content | string | 联系方式 |
| sources | list | 联系方式来源 |

错误返回值

| code | msg | 说明 |
|---|---|---|
| &nbsp;406 | &nbsp;PIN已被使用 / 请求参数有误(keywords参数不能为空，类型需为list) | &nbsp; |
| 407 | PIN时间戳和服务器时间误差超过10分钟 |    |
| 408 | Access Secrect 验证失败 |    |
| 409 | 缺少 X-AK-KEY 或者 X-AK-PIN 或 X-AK-TS 请求头 |    |
| 410 | Access Key 不存在 |    |
| 411 | 访问 IP 不在白名单之列 |    |
| 412 | Access Key 已被禁用 |    |
| 500 | 服务器错误 |    |
| 1000 | 账户已过期 |    |
| 1001 | 请求额度不足 |    |
| 1002 | 账户无调用权限 |    |
| 1003 | 请求并发超限 | |


错误代码参考 [错误码定义](http://apidoc.weiwenjia.com/docs/skb-open-dev/7967638-7967721.md)