## 企业搜索(指定条件)


### API路径

    services/v4/rest/enterprise/batch/enterpriseSearch

### 请求方法

POST

###   请求参数
body 参数

| 参数 | 类型 | 说明 | 示例 |
|---|---|---|---|
| condition | object | 搜索条件 | &nbsp; |
| page | int | 页数（默认为1） | &nbsp; |
| size | int | 每页数量（默认为10，最大100） | &nbsp; |

### 搜索条件（condition）
| 参数 | 类型 | 说明 | 示例 | 是否必须 |
|---|---|---|---| --- |
| firstIndustry | array | 一级行业 | [ "A" ] | 否 |
| secondIndustry | array | 二级行业 | [ "11" ] | 否 |
| thirdIndustry | array | 三级行业 | [ "110" ] | 否 |
| fourIndustry | array | 四级行业 | [ "1100" ] | 否 |
| positionReleaseTime | string | 职位发布时间（开始时间-结束时间）(毫秒) | "1704384000000-1705075199999" | 否 |
| entType | array | 企业类型 | [ 1 ] | 否 |
| entStatus | array | 企业状态 | [ "1", "9" ] | 否 |
| recProvince | array | 岗位地址省code | [ "34" ] | 否 |
| recCity | array | 岗位地址市code | [ "3501" ] | 否 |
| recDistrict | array | 岗位地址区县code | [ "110114" ] | 否 |
| esDate | string | 成立时间（开始时间-结束时间）(毫秒)  | "1704384000000-1705075199999" | 否 |
| regProvince | array | 注册地址省code | [ "34" ] | 否 |
| regCity | array | 注册地址市code | [ "3501" ] | 否 |
| regDistrict | array | 注册地址区县code | [ "110114" ] | 否 |
| keywords | string | 关键词(企业名称，产品名称) | "小米" | 否 |
| entNameEng | string | 企业英文名称 | "NET263CO., LTD." | 否 |
| regCapUnify | string | 注册资本(最小值,最大值,单位默认是：万元) | "1,100" | 否 |
| contacts | array | 联系方式 | [ "1", "2" ] | 否 |
| recruitFilter | object | 企业招聘联合筛选 |  | 否 |

### 企业招聘搜索条件（recruitFilter）
| 参数 | 类型 | 说明 | 示例 | 是否必须 |
|---|---|---|---| --- |
| releaseDate | string | 职位发布时间（开始时间-结束时间）(毫秒) | "1704384000000-1705075199999" | 否 |
| recProvince | array | 岗位地址省code | [ "34" ] | 否 |
| recCity | array | 岗位地址市code | [ "3501" ] | 否 |
| recDistrict | array | 岗位地址区县code | [ "110114" ] | 否 |

注：岗位省市区只需要存在一个


配置项详见 [配置参数](../../skb-open-dev-1e2hc27loo8qp/skb-open-dev-1ff4f7m3r1lms.md)

### 接口入参要求：
1. 当企业英文名称未传时，行业必须存在至少一个条件
2. 注册地址，岗位地址，行业 筛选是应给出最小搜索条件

### 调用样例

    http://${host}/services/v4/rest/enterprise/batch/enterpriseSearch
	
### 返回结果

JSON示例

    {
    "error_code": 0,
    "message": "",
	"size": 1,	// 页数条数
    "total": 51,	// 总数
    "page": 1,	// 页数
    "data": [
        {
            "pid": "52baef8e5153419a2548b361f1b2f68b",	// 企业唯一id
            "entname": "山东能源集团有限公司",	// 企业名称
            "ent_name_eng": "GUIZHOU FUXIN SHANDA TECHNOLOGY CO., LTD.",	// 企业英文名称
            "establish_date": 826588800000,		// 成立日期(毫秒)
            "legal_person": "李**",		// 法人
            "reg_address": "山东省济南市高新区舜华路28号",	// 注册地址
            "geo_address": "山东省济南市高新区舜华路28号",	// 通讯地址
            "contacts": [
				// 联系方式
                {
                    "content": "1866076***",
                    "contact": "张**"
                }
            ],
            "ent_status": "在营（开业）企业",	// 营业状态
            "first_industry": [	// 一级行业
                "采矿业"
            ],
            "second_industry": [	// 二级行业
                "开采专业及辅助性活动"
            ],
            "third_industry": [		// 三级行业
                "煤炭开采和洗选专业及辅助性活动"
            ],
            "four_industry": [		// 四级行业
                "煤炭开采和洗选专业及辅助性活动"
            ]
        }
    ]
}


错误返回值

| code | msg | 说明 |
|---|---|---|
| &nbsp;406 | &nbsp;PIN已被使用 / 请求参数有误(keywords参数不能为空，类型需为string) | &nbsp; |
| 407 | PIN时间戳和服务器时间误差超过10分钟 |    |
| 408 | Access Secrect 验证失败 |    |
| 409 | 缺少 X-AK-KEY 或者 X-AK-PIN 或 X-AK-TS 请求头 |    |
| 410 | Access Key 不存在 |    |
| 411 | 访问 IP 不在白名单之列 |    |
| 412 | Access Key 已被禁用 |    |
| 500 | 服务器错误 |    |
| 1000 | 账户已过期 |    |
| 1001 | 请求额度不足 |    |
| 1002 | 账户无调用权限 |    |
| 1003 | 请求并发超限 | |

错误代码参考 [错误码定义](http://apidoc.weiwenjia.com/docs/skb-open-dev/7967638-7967721.md)